function [X,Y, output] = ge_gplot(A,xy, varargin)
%% [Xout,Yout, output] = ge_gplot(A,xy)
% A is the adjacency matrix for the network.  
% All units in arg 'xy' are in decimal degree coordinates (WGS84)
% AuthorizedOptions = {'id',...
%                      'idTag', ...
%                      'name',...
%                     'timeStamp', ...
%                     'timeSpanStart', ...
%                     'timeSpanStop', ...
%                      'description', ...
%                      'visibility', ...
%                      'LineWidth', ...
%                      'LineColor', ...
%                      'PolyColor', ...
%                      'extrude', ...
%                      'altitude', ...
%                      'altitudeMode', ...
%                      'tessellate', ...
%                      'Snippet'};
%
%GPLOT Plot graph, as in "graph theory".
%   GPLOT(A,xy) plots the graph specified by A and xy. A graph, G, is
%   a set of nodes numbered from 1 to n, and a set of connections, or
%   edges, between them.  
%
%   In order to plot G, two matrices are needed. The adjacency matrix,
%   A, has a(i,j) nonzero if and only if node i is connected to node
%   j.  The coordinates array, xy, is an n-by-2 matrix with the
%   position for node i in the i-th row, xy(i,:) = [x(i) y(i)].
%   
%   GPLOT(A,xy,LineSpec) uses line type and color specified in the
%   string LineSpec. See PLOT for possibilities.
%
%   [X,Y] = GPLOT(A,xy) returns the NaN-punctuated vectors
%   X and Y without actually generating a plot. These vectors
%   can be used to generate the plot at a later time if desired.
%   
%   See also SPY, TREEPLOT.

%   John Gilbert, 1991.
%   Modified 1-21-91, LS; 2-28-92, 6-16-92 CBM.
%   Copyright 1984-2002 The MathWorks, Inc. 
%   $Revision: 5.12 $  $Date: 2002/04/15 04:13:43 $
%   OF Course... modified for ge_toolbox.:  ScottDavis 2007-22-01

AuthorizedOptions = {'id',...
                     'idTag', ...
                     'name',...
                     'timeStamp', ...
                     'timeSpanStart', ...
                     'timeSpanStop', ...
                     'description', ...
                     'visibility', ...
                     'LineWidth', ...
                     'LineColor', ...
                     'PolyColor', ...
                     'extrude', ...
                     'altitude', ...
                     'altitudeMode', ...
                     'tessellate', ...
                     'Snippet'};

for k = 1:2:length(varargin(:))
    if ~strcmp(varargin{k}, AuthorizedOptions)
        error(['Unauthorized parameter name ' 39 varargin{k} 39 ' in ' 10,...
            'parameter/value passed to ' 39 mfilename 39 '.']);
    end
end
                     
                            
if ( isempty( A ) | isempty(xy) )
    error('empty coordinates passed to ge_gplot(...).');
end


         id = 'default_ge_gplot';
      idTag = 'id';
       name = 'ge_gplot';
description = '';
    timeStamp = ' ';
timeSpanStart = ' ';
 timeSpanStop = ' ';
 visibility = 1;
  LineColor = 'ffffffff';
  PolyColor = 'ffffffff';
  LineWidth = 1.0;
    Snippet = '';
   altitude = 1.0;
     extrude = 1;
     tessellate = 0;
 altitudeMode = 'clampToGround';

v = ge_parse_pairs(varargin);

for j = 1:length(v)
    eval(v{j});
end

[i,j] = find(A);
[ignore, p] = sort(max(i,j));
i = i(p);
j = j(p);

% Create a long, NaN-separated list of line segments,
% rather than individual segments.

X = [ xy(i,1) xy(j,1) repmat(NaN,size(i))]';
Y = [ xy(i,2) xy(j,2) repmat(NaN,size(i))]';
X = X(:);
Y = Y(:);

output = ge_poly(Y,X, ...
                        'id', id, ...
                        'idTag', idTag, ...
                        'name', name, ...
                        'description', description, ...
                        'timeStamp', timeStamp, ...
                        'timeSpanStart', timeSpanStart, ...
                        'timeSpanStop', timeSpanStop, ...
                        'visibility', visibility, ...
                        'LineColor', LineColor, ...
                        'PolyColor', PolyColor, ...
                        'LineWidth', LineWidth, ...
                        'Snippet', Snippet, ...
                        'altitude', altitude, ...
                        'extrude', extrude, ...
                        'tessellate', tessellate, ...
                        'altitudeMode', altitudeMode);


