function [outData,pathname,flag] = jma_catalog
% function jma_catalog
%
%   Read Japan Meteorological Agency (JMA) data earthquake catalog
%

    flag = 1; % data is properly read (flag = 0, not properly read)
    [filename,pathname] = uigetfile({'*.*'},' Open earthquake file');
    if isequal(filename,0)
%        disp('  User selected Cancel');
        return
    else
        disp('  ----- earthquake data -----');
        disp(['  User selected', fullfile(pathname, filename)]);
    end
	myData = textread(fullfile(pathname, filename), '%s', 'delimiter', '\n', 'whitespace', '');
	outData = zeros(length(myData), 15);
nerror = 0;
hm = wait_calc_window;      % waiting window...
for i = 1:length(myData)
	try 
            lon_deg = str2double(myData{i}(33:36));
            lon_min = str2double(myData{i}(37:41))/100;
            outData(i,1) = lon_deg + lon_min/60.0;              % longitude
            lat_deg = str2double(myData{i}(22:24));
            lat_min = str2double(myData{i}(25:28))/100;
            outData(i,2) = lat_deg + lat_min/60.0;              % latitude
            outData(i,3) = str2double(myData{i}(2:5));          % Year
            outData(i,4) = str2double(myData{i}(6:7));          % Month
            outData(i,5) = str2double(myData{i}(8:9));          % Day
            outData(i,6) = str2double(myData{i}(53:54))/10.;	% Magnitude
            if isnan(outData(i,6))
            outData(i,6) = -9.9;      % Magnitude (No M info, temp assigned -9.9)
            end
            outData(i,7) = str2double(myData{i}(45:49))/100.;	% Depth             
            outData(i,8) = str2double(myData{i}(10:11));        % Hour
            outData(i,9) = str2double(myData{i}(12:13));        % Minute
            outData(i,10) = 0.0;                                % Nodal 1: strike
            outData(i,11) = 0.0;                                % Nodal 1: dip
            outData(i,12) = 0.0;                                % Nodal 1: rake
            outData(i,13) = 0.0;                                % Nodal 2: strike
            outData(i,14) = 0.0;                                % Nodal 2: dip
            outData(i,15) = 0.0;                                % Nodal 2: rake
%             if isnan(outData(i,1)) || isnan(outData(i,3)) || isnan(outData(i,6))
%                 nerror = nerror + 1;
%             end
    catch
        disp(['Import: Problem in line ' num2str(i) ' of ' filename '. Line ignored.']);
        nerror = nerror + 1;
    end
        if nerror > 9
          disp('!! Warning !! This may not be a properly formatted JMA catalog.');
          h = errordlg('This may not be a properly formatted JMA catalog.');
          flag = 0;         % transmit the error info...
          waitfor(h);
          close(hm)
          return;
        end
end
close(hm)

% z map format
%
% 1)lon, 2)lat, 3)year, 4)month, 5)day, 6)M, 7)depth, 8)hr, 9)min, 10)strike1, 11)dip1, 12)rake1,
% 13)strike2, 14)dip2, 15)rake2
%